@@ -44,12 +44,12 @@ class GeneratorXmlThreeDotThree(AbstractGeneratorXml):
         dom.setAttribute('xmlns:tfd',"http://www.sat.gob.mx/TimbreFiscalDigital")
         dom.setAttribute('xmlns:implocal',"http://www.sat.gob.mx/implocal")
         dom.setAttribute('xmlns:notariospublicos',"http://www.sat.gob.mx/notariospublicos")
-        dom.setAttribute('Version', self.global_data.get('version', ''))
+        dom.setAttribute('Version', self.data.get('version', ''))
         dom.setAttribute('Serie', self.data.get('serie', ''))
         dom.setAttribute('Folio', self.data.get('folio', ''))
         dom.setAttribute('Fecha', self.data.get('fecha'))
         dom.setAttribute('Sello', '')
-        dom.setAttribute('NoCertificado', self.global_data.get('no_certificado'))
+        dom.setAttribute('NoCertificado', self.data.get('no_certificado'))
         dom.setAttribute('Certificado','')
         dom.setAttribute('TipoDeComprobante', self.tipo_objeto)
         dom.setAttribute('LugarExpedicion', self.data.get('codigo_postal', ''))
@@ -65,7 +65,7 @@ class GeneratorXmlThreeDotThree(AbstractGeneratorXml):
         dom.appendChild(self.get_emisor())
         dom.appendChild(self.get_receptor())
 
-        if (self.tipo_objeto == INGRESO) or (self.tipo_objeto == EGRESO and not self.global_data.get('concepto_fijo')):
+        if (self.tipo_objeto == INGRESO) or (self.tipo_objeto == EGRESO and not self.data.get('concepto_fijo')):
             dom.setAttribute('FormaPago', self.data.get('forma_pago'))
             dom.setAttribute('CondicionesDePago', self.data.get('condicion_pago'))
             # dom.setAttribute('Descuento', '0.00') # 'Opcional'
@@ -99,7 +99,7 @@ class GeneratorXmlThreeDotThree(AbstractGeneratorXml):
                 for concepto in conceptos_list:
                     conceptos.appendChild(self.get_conceptos(concepto))
                 dom.appendChild(conceptos)
-        elif self.tipo_objeto == EGRESO and self.global_data.get('concepto_fijo'):
+        elif self.tipo_objeto == EGRESO and self.data.get('concepto_fijo'):
             dom.setAttribute('FormaPago',self.data.get('forma_pago'))
             dom.setAttribute('CondicionesDePago', self.data.get('condicion_pago'))
             dom.setAttribute('MetodoPago', self.data.get('metodo_pago'))
