@@ -15,6 +15,7 @@ class GeneratorXmlFourDotZero(AbstractGeneratorXml):
     def __init__(self, data):
         super(self.__class__, self).__init__(data)
         self.version = '4.0'
+        self.data = data
         self.algoritmoSha = SHA256
         self.__cadena_original = ''
         self.impuestos_trasladados = self.data.get('impuestos_trasladados', [])
@@ -25,18 +26,18 @@ class GeneratorXmlFourDotZero(AbstractGeneratorXml):
         dom = self.dom.childNodes[0]
         if self.data.get('tipo_comprobante') == 4: #recibo donativo
             dom.setAttribute('xsi:schemaLocation',
-                             'http://www.sat.gob.mx/cfd/3 ' +
-                             'http://www.sat.gob.mx/sitio_internet/cfd/3/cfdv33.xsd ' +
+                             'http://www.sat.gob.mx/cfd/4 ' +
+                             'http://www.sat.gob.mx/sitio_internet/cfd/4/cfdv40.xsd ' +
                              'http://www.sat.gob.mx/donat ' +
                              'http://www.sat.gob.mx/sitio_internet/cfd/donat/donat11.xsd')
             dom.setAttribute('xmlns:donat', 'http://www.sat.gob.mx/donat')
         elif self.complemento == COMPLEMENTO_CARTA_PORTE:
-            dom.setAttribute('xmlns:cfdi', 'http://www.sat.gob.mx/cfd/3')
+            dom.setAttribute('xmlns:cfdi', 'http://www.sat.gob.mx/cfd/4')
             dom.setAttribute('xmlns:xsi', 'http://www.w3.org/2001/XMLSchema-instance')
             dom.setAttribute('xmlns:cartaporte20', 'http://www.sat.gob.mx/CartaPorte20')
             dom.setAttribute('xsi:schemaLocation',
-                             'http://www.sat.gob.mx/cfd/3 ' +
-                             'http://www.sat.gob.mx/sitio_internet/cfd/3/cfdv33.xsd ' +
+                             'http://www.sat.gob.mx/cfd/4 ' +
+                             'http://www.sat.gob.mx/sitio_internet/cfd/4/cfdv40.xsd ' +
                              'http://www.sat.gob.mx/CartaPorte20 ' +
                              'http://www.sat.gob.mx/sitio_internet/cfd/CartaPorte/CartaPorte20.xsd')
         else:
@@ -44,18 +45,18 @@ class GeneratorXmlFourDotZero(AbstractGeneratorXml):
             dom.setAttribute('xmlns:xsi', 'http://www.w3.org/2001/XMLSchema-instance')
             dom.setAttribute('xmlns:cfdi', 'http://www.sat.gob.mx/cfd/4')
 
-        dom.setAttribute('Version', self.global_data.get('version', ''))
+        dom.setAttribute('Version', self.data.get('version', ''))
         dom.setAttribute('Serie', self.data.get('serie', ''))
         dom.setAttribute('Folio', self.data.get('folio', ''))
         dom.setAttribute('Fecha', self.data.get('fecha'))
         dom.setAttribute('Sello', '')
-        dom.setAttribute('NoCertificado', self.global_data.get('no_certificado'))
-        dom.setAttribute('Certificado', self.global_data.get('certificado'))
+        dom.setAttribute('NoCertificado', self.data.get('no_certificado'))
+        dom.setAttribute('Certificado', self.data.get('certificado'))
         dom.setAttribute('TipoDeComprobante', self.tipo_objeto)
-        dom.setAttribute('LugarExpedicion', self.data.get('codigo_postal', ''))
+        dom.setAttribute('LugarExpedicion', self.data.get('lugar_expedicion', ''))
         dom.setAttribute('Exportacion', self.data.get('exportacion', '01'))
 
-        if self.data.get('confirmacion') and len(self.data.get('confirmacion', [])) == 5:
+        if self.data.get('confirmacion'):
             dom.setAttribute('Confirmacion', self.data.get('confirmacion'))  # opcional
 
         dom.appendChild(self.get_emisor())
@@ -68,9 +69,8 @@ class GeneratorXmlFourDotZero(AbstractGeneratorXml):
                 raise Exception('Debe especificar el tipo de relación de los documentos')
             dom.appendChild(self.get_cfdi_relacionados(self.data.get('cfdi_relacionados', [])))
 
-        if (self.tipo_objeto == INGRESO) or (self.tipo_objeto == EGRESO and not self.global_data.get('concepto_fijo')):
+        if self.tipo_objeto == INGRESO or self.tipo_objeto == EGRESO:
             dom.setAttribute('FormaPago', self.data.get('forma_pago'))
-            dom.setAttribute('CondicionesDePago', self.data.get('condicion_pago')) # hasta 1000 caracteres
             # dom.setAttribute('Descuento', '0.00') # 'Opcional'
             dom.setAttribute('MetodoPago', self.data.get('metodo_pago'))
             # Campos que solo en ingreso no son fijos
@@ -88,6 +88,7 @@ class GeneratorXmlFourDotZero(AbstractGeneratorXml):
             dom.setAttribute('SubTotal','0')
             dom.setAttribute('Moneda','XXX')
             dom.setAttribute('Total','0')
+            dom.setAttribute('Exportacion', self.data.get('exportacion', '01'))
             dom.appendChild(self.get_concepto_fijo())
         elif self.tipo_objeto == TRASLADO:
             dom.setAttribute('SubTotal','0')
@@ -95,18 +96,6 @@ class GeneratorXmlFourDotZero(AbstractGeneratorXml):
             dom.setAttribute('Total','0')
             if len(conceptos_list) > 0:
                 dom.appendChild(self.get_conceptos(conceptos_list))
-        elif self.tipo_objeto == EGRESO and self.global_data.get('concepto_fijo'):
-            dom.setAttribute('FormaPago',self.data.get('forma_pago'))
-            dom.setAttribute('CondicionesDePago', self.data.get('condicion_pago'))
-            dom.setAttribute('MetodoPago', self.data.get('metodo_pago'))
-            dom.setAttribute('Moneda', self.data.get('moneda'))  # 'Peso Mexicano'
-            # 'Opcional solo cuando moneda es distinta de MXN'
-            dom.setAttribute('TipoCambio', '1' if self.data.get('moneda') == 'MXN' else self.data.get('tipo_cambio'))
-            dom.setAttribute('SubTotal', str(self.data.get('subtotal')))
-            dom.setAttribute('Total', str(self.data.get('total')))
-            dom.appendChild(self.get_concepto_fijo())
-            if bool(self.data.get('aplica_retencion', False)) or bool(self.data.get('aplica_traslado', False)):
-                dom.appendChild(self.get_impuestos())
         if self.data.get('tipo_comprobante') in [4, 5] or self.complemento in [COMPLEMENTO_PAGO, COMPLEMENTO_CARTA_PORTE]:
             dom.appendChild(self.get_complementos())
         self.dom = dom
@@ -130,7 +119,6 @@ class GeneratorXmlFourDotZero(AbstractGeneratorXml):
             emisor.setAttribute('Rfc', self.data.get('emisor_rfc'))
             emisor.setAttribute('Nombre', replace(self.data.get('emisor_nombre', '')).strip())
             emisor.setAttribute('RegimenFiscal', self.data.get('regimen_fiscal'))
-            # emisor.setAttribute('FacAtrAdquirente', self.data.get('fac_atr_adquirente')) #Pendiente de agregar
             return emisor
         except Exception as e:
             raise Exception("Ocurrio un error al agregar al emisor. Error::: " + str(e))
@@ -140,7 +128,6 @@ class GeneratorXmlFourDotZero(AbstractGeneratorXml):
             receptor = self.dom.createElement('cfdi:Receptor')
             receptor.setAttribute('Rfc', self.data.get('receptor_rfc'))
             receptor.setAttribute('Nombre',replace(self.data.get('receptor_nombre', '')).strip())
-            #if self.data.get('receptor_rfc') not in ['XAXX010101000', 'XEXX010101000']:
             receptor.setAttribute('DomicilioFiscalReceptor', self.data.get('domicilio_fiscal_receptor', ''))
             if self.data.get('receptor_residencia_fiscal') != 'MEX':
                 receptor.setAttribute('ResidenciaFiscal', self.data.get('receptor_residencia_fiscal'))
@@ -164,6 +151,7 @@ class GeneratorXmlFourDotZero(AbstractGeneratorXml):
                 concepto.setAttribute('Descripcion','Pago')
                 concepto.setAttribute('ValorUnitario','0')
                 concepto.setAttribute('Importe','0')
+                concepto.setAttribute('ObjetoImp', '01')
             elif self.tipo_objeto == EGRESO:
                 if self.data.get('descripcion', '') != '':
                     concepto.setAttribute('Descripcion',replace(self.data.get('descripcion', '').strip()))
