@@ -19,7 +19,6 @@ class AbstractGeneratorXml(object):
     __metaclass__ = ABCMeta
 
     def __init__(self, data):
-        self.global_data = data
         self.data = data.get('data')
         self.dir_xml = os.path.dirname(os.path.abspath(__file__))
         self.dom = parse(self.dir_xml + '/comprobante.xml')
@@ -37,7 +36,7 @@ class AbstractGeneratorXml(object):
 
     def create_xml(self, certificado_file_cer64, certificado_file_pem64):
         self.generate_xml()
-        if self.global_data.get('provider') == 'solucion_factible':
+        if self.get('provider') == 'solucion_factible':
             self.set_certificado(certificado_file_cer64)
             self.set_sello(certificado_file_pem64)
 
